@@ -1,6 +1,7 @@
 #include "CPMemUtils.h"
 #include "CPTimer.h"
 
+
 unsigned long getPhysicalMemorySize()
 {
 #ifdef __APPLE__
@@ -106,12 +107,12 @@ unsigned long getCurrentProcessMemoryUsage()
 		return 0;
 		//std::cout << "Could not open process (Error " << ::GetLastError() << ")" << std::endl;
 #else
-	struct mallinfo info;
+	//struct mallinfo info;
 
 	/* what is the largest ECB heap buffer currently available? */
-	info = mallinfo();
+	//info = mallinfo();
 
-	return info.arena;
+	return 0; //info.arena;
 
 #endif
 #endif
